
dialogId("dlg-x-poster1", "font_poster", "We recommend subject the enclosed material to thorough tests of holiness. Due to the lack of equipment we performed only the basic tests and the results are more than promising.")
dialogStr("We raden aan het bijgevoegde materiaal zorgvuldig te testen op Heiligheid. Wegens gebrek aan geschikte apparatuur konden we alleen de meest eenvoudige test uitvoeren en de resultaten zijn veelbelovend.")


dialogId("dlg-x-poster2", "font_poster", "Bombing some of the grails with ultradirty words, we measured sometimes even 3 Santa Clauses, some of them withstanded the circumstances pressure of 0.8 jobs for the period of one minute!")
dialogStr("We hebben de Gralen gebombardeerd met vreselijke schuttingtaal en bij een aantal zagen we een respons van meer dan 3 Sinterklaas. Sommige waren in staat de werkdruk van 0.8 banen gedurende een hele minuut te weerstaan.")


dialogId("dlg-x-poster3", "font_poster", "It is also possible that we have encountered the whole Holy Service.")
dialogStr("Het is ook mogelijk dat we een veel groter deel van het Heilig Servies hebben gevonden.")

